## Summary

<!-- Brief description of what this PR does -->

## Changes

-

## Test Plan

- [ ] Tests pass locally (`uv run pytest`)
- [ ] Linting passes (`uv run ruff check`)
- [ ] Type checking passes (`uv run pyright`)
- [ ] Zing has been run on the PR (`/zing:pr-audit` or `/zing:build-audit`)
